# Generated by Django 4.1.5 on 2023-01-04 23:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('scrobbles', '0002_scrobble_counted'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='scrobble',
            name='counted',
        ),
        migrations.AddField(
            model_name='scrobble',
            name='in_progress',
            field=models.BooleanField(default=True),
        ),
    ]
