# Generated by Django 4.1.5 on 2023-02-03 23:36

from django.db import migrations, models
import scrobbles.models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('scrobbles', '0014_audioscrobblertsvimport_process_log'),
    ]

    operations = [
        migrations.AddField(
            model_name='audioscrobblertsvimport',
            name='uuid',
            field=models.UUIDField(default=uuid.uuid4, editable=False),
        ),
        migrations.AlterField(
            model_name='audioscrobblertsvimport',
            name='tsv_file',
            field=models.FileField(
                blank=True,
                null=True,
                upload_to=scrobbles.models.AudioScrobblerTSVImport.get_path,
            ),
        ),
    ]
