# Generated by Django 4.1.5 on 2023-01-14 21:23

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('sports', '0002_rename_start_utc_sportevent_start'),
        ('scrobbles', '0007_scrobble_podcast_episode'),
    ]

    operations = [
        migrations.AddField(
            model_name='scrobble',
            name='sport_event',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                to='sports.sportevent',
            ),
        ),
    ]
