# Generated by Django 4.1.5 on 2023-01-07 20:03

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('music', '0001_initial'),
        ('videos', '0003_alter_video_run_time_ticks'),
        ('scrobbles', '0005_alter_scrobble_playback_position_ticks'),
    ]

    operations = [
        migrations.AddField(
            model_name='scrobble',
            name='track',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                to='music.track',
            ),
        ),
        migrations.AlterField(
            model_name='scrobble',
            name='video',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                to='videos.video',
            ),
        ),
    ]
