# Generated by Django 4.1.5 on 2023-02-27 04:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('music', '0010_artist_biography_artist_theaudiodb_genre_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='artist',
            name='thumbnail',
            field=models.ImageField(
                blank=True, null=True, upload_to='artist/'
            ),
        ),
    ]
