# Generated by Django 4.1.5 on 2023-01-11 03:23

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('videos', '0004_series_uuid_video_uuid'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='video',
            options={},
        ),
        migrations.AlterUniqueTogether(
            name='video',
            unique_together={('title', 'imdb_id')},
        ),
    ]
