# Generated by Django 4.1.5 on 2023-01-11 03:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('music', '0003_album_uuid_artist_uuid_track_uuid'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='artist',
            options={},
        ),
        migrations.AlterField(
            model_name='album',
            name='musicbrainz_id',
            field=models.CharField(
                blank=True, max_length=255, null=True, unique=True
            ),
        ),
        migrations.AlterField(
            model_name='track',
            name='musicbrainz_id',
            field=models.CharField(
                blank=True, max_length=255, null=True, unique=True
            ),
        ),
        migrations.AlterUniqueTogether(
            name='artist',
            unique_together={('name', 'musicbrainz_id')},
        ),
    ]
