# Generated by Django 4.1.5 on 2023-01-13 01:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('videos', '0005_alter_video_options_alter_video_unique_together'),
    ]

    operations = [
        migrations.AlterField(
            model_name='video',
            name='year',
            field=models.IntegerField(blank=True, null=True),
        ),
    ]
