{% extends "base_list.html" %}
{% load mathfilters %}

{% block title %}{{object.name}}{% endblock %}

{% block lists %}
<div class="row">

    {% if object.thumbnail %}
    <p style="float:left; width:300px; margin-right:10px;">
        <img style="border:1px solid #ccc;" src="{{artist.thumbnail.url}}" width=300 height=300 />
    </p>
    {% else %}
    {% if object.album_set.first.cover_image %}
    <p style="float:left; width:302px; padding:0; border: 1px solid #ccc">
        <img src="{{object.album_set.first.cover_image.url}}" width=300 height=300 />
    </p>
    {% endif %}
    {% endif %}
    <div style="float:left; width:600px; margin-left:10px; ">
        {% if artist.biography %}
        <p>{{artist.biography|safe|linebreaks|truncatewords:160}}</p>
        <hr/>
        {% endif %}
        <p><a href="{{artist.mb_link}}">Musicbrainz</a></p>
    </div>
</div>
<div class="row">
    <p>{{artist.scrobbles.count}} scrobbles</p>
    {% if charts %}
    <p>{% for chart in charts %}<em><a href="{{chart.link}}">{{chart}}</a></em>{% if forloop.last %}{% else %} | {% endif %}{% endfor %}</p>
    {% endif %}
    <div class="col-md">
        <h3>Top tracks</h3>
        <div class="table-responsive">
            <table class="table table-striped table-sm">
            <thead>
                <tr>
                    <th scope="col">Rank</th>
                    <th scope="col">Track</th>
                    <th scope="col">Album</th>
                    <th scope="col">Count</th>
                    <th scope="col"></th>
                </tr>
            </thead>
            <tbody>
                {% for track in object.tracks %}
                <tr>
                    <td>{{rank}}#1</td>
                    <td><a href="{{track.get_absolute_url}}">{{track.title}}</a></td>
                    <td><a href="{{track.album.get_absolute_url}}">{{track.album}}</a></td>
                    <td>{{track.scrobble_count}}</td>
                    <td>
                        <div class="progress-bar" style="margin-right:5px;">
                            <span class="progress-bar-fill" style="width: {{track.scrobble_count|mul:10}}%;"></span>
                        </div>
                    </td>
                </tr>
                {% endfor %}
            </tbody>
            </table>
        </div>
    </div>
</div>
<div class="row">
    <div class="col-md">
        <h3>Last scrobbles</h3>
        <div class="table-responsive">
            <table class="table table-striped table-sm">
            <thead>
                <tr>
                    <th scope="col">Date</th>
                    <th scope="col">Track</th>
                    <th scope="col">Album</th>
                </tr>
            </thead>
            <tbody>
                {% for scrobble in object.scrobbles %}
                <tr>
                    <td>{{scrobble.timestamp}}</td>
                    <td><a href="{{scrobble.track.get_absolute_url}}">{{scrobble.track.title}}</a></td>
                    <td><a href="{{scrobble.track.album.get_absolute_url}}">{{scrobble.track.album.name}}</a></td>
                </tr>
                {% endfor %}
            </tbody>
            </table>
        </div>
    </div>
</div>
{% endblock %}
