# Generated by Django 4.1.5 on 2023-01-12 17:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('podcasts', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='episode',
            name='run_time',
            field=models.CharField(blank=True, max_length=8, null=True),
        ),
        migrations.AddField(
            model_name='episode',
            name='run_time_ticks',
            field=models.PositiveBigIntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='episode',
            name='podcast',
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.DO_NOTHING,
                to='podcasts.podcast',
            ),
        ),
    ]
