{% extends "base_list.html" %}
{% load urlreplace %}

{% block title %}Artists{% endblock %}

{% block lists %}
<div class="row">
    <p class="view">
        <span class="view-links">
            {% if view == 'grid' %}
                View as <a href="?{% urlreplace view='list' %}">List</a>
            {% else %}
                View as <a href="?{% urlreplace view='grid' %}">Grid</a>
            {% endif %}
        </span>
    </p>
    <p class="pagination">
        <span class="page-links">
            {% if page_obj.has_previous %}
                <a href="?{% urlreplace page=page_obj.previous_page_number %}">prev</a>
            {% endif %}
                <span class="page-current">
                    Page {{ page_obj.number }} of {{ page_obj.paginator.num_pages }}
                </span>
            {% if page_obj.has_next %}
                <a href="?{% urlreplace page=page_obj.next_page_number %}">next</a>
            {% endif %}
        </span>
    </p>
    <hr />

    {% if view == 'grid' %}
    <div>
        {% for artist in object_list %}
        {% if artist.thumbnail %}
        <dl style="width: 130px; float: left; margin-right:10px;">
            <dd><img src="{{artist.thumbnail.url}}" width=120 height=120 /></dd>
        </dl>
        {% endif %}
        {% endfor %}
    </div>
    {% else %}
    <div class="col-md">
        <div class="table-responsive">
            <table class="table table-striped table-sm">
            <thead>
                <tr>
                    <th scope="col">Artist</th>
                    <th scope="col">Scrobbles</th>
                    <th scope="col">All time</th>
                </tr>
            </thead>
            <tbody>
                {% for artist in object_list %}
                <tr>
                    <td><a href="{{artist.get_absolute_url}}">{{artist}}</a></td>
                    <td>{{artist.scrobbles.count}}</td>
                    <td></td>
                </tr>
                {% endfor %}
            </tbody>
            </table>
        </div>
    </div>
    {% endif %}

    <div class="pagination" style="margin-bottom:50px;">
        <span class="page-links">
            {% if page_obj.has_previous %}
                <a href="?{% urlreplace page=page_obj.previous_page_number %}">prev</a>
            {% endif %}
                <span class="page-current">
                    Page {{ page_obj.number }} of {{ page_obj.paginator.num_pages }}
                </span>
            {% if page_obj.has_next %}
                <a href="?{% urlreplace page=page_obj.next_page_number %}">next</a>
            {% endif %}
        </span>
    </div>
</div>
{% endblock %}
