# Generated by Django 4.1.5 on 2023-02-27 03:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('music', '0009_alter_track_musicbrainz_id_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='artist',
            name='biography',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='artist',
            name='theaudiodb_genre',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='artist',
            name='theaudiodb_mood',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
