# Generated by Django 4.1.5 on 2023-01-22 21:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sports', '0005_remove_sportevent_season'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sportevent',
            name='event_type',
            field=models.CharField(
                choices=[('UK', 'Unknown'), ('GA', 'Game'), ('MA', 'Match')],
                default='UK',
                max_length=2,
            ),
        ),
    ]
